import { Account, CheckDepositStatus, Customer, Sort, Tags, Transaction } from "../types";
import { CheckDeposit, CreateCheckDepositRequest, PatchCheckDepositRequest, UploadCheckDepositRequest } from "../types";
import { UnitResponse, Include, UnitConfig, BaseListParams } from "../types";
import { BaseResource } from "./baseResource";
import { responseEncoding, ResponseType } from "axios";
export declare class CheckDeposits extends BaseResource {
    constructor(token: string, basePath: string, config?: UnitConfig);
    list(params?: CheckDepositListParams): Promise<UnitResponse<CheckDeposit[]>>;
    create(request: CreateCheckDepositRequest): Promise<UnitResponse<CheckDeposit>>;
    get(id: string, include?: string): Promise<UnitResponse<CheckDeposit> & Include<(Customer | Account | Transaction)[]>>;
    update(request: PatchCheckDepositRequest): Promise<UnitResponse<CheckDeposit>>;
    upload(request: UploadCheckDepositRequest): Promise<UnitResponse<CheckDeposit>>;
    getImage(id: string, front?: boolean, responseEncoding?: responseEncoding, responseType?: ResponseType): Promise<string>;
    confirm(id: string): Promise<UnitResponse<CheckDeposit>>;
}
export interface CheckDepositListParams extends BaseListParams {
    /**
     * Optional. Filters the results by the specified account id.
     * default: empty
     */
    accountId?: string;
    /**
     * Optional. Filters the results by the specified customer id.
     * default: empty
     */
    customerId?: string;
    /**
     * Optional. Filter Applications by [Tags](https://developers.unit.co/#tags).
     * default: empty
     */
    tags?: Tags;
    /**
     * Optional. Filter results by [Check Deposit Status](https://developers.unit.co/check-deposits#check-deposit-status).
     */
    status?: CheckDepositStatus[];
    /**
     * Optional. Leave empty or provide sort=createdAt for ascending order. Provide sort=-createdAt (leading minus sign) for descending order.
     */
    sort?: Sort;
    /**
     * Optional. Related resource available to include: customer. See [Getting Related Resources](https://developers.unit.co/#intro-getting-related-resources).
     * default: empty
     */
    include?: string;
}
