"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Transactions = void 0;
const baseResource_1 = require("./baseResource");
class Transactions extends baseResource_1.BaseResource {
    constructor(token, basePath, config) {
        super(token, basePath, config);
    }
    /**
     *
     * @param accountId
     * @param transactionId
     * @param customerId - Optional. Filters the result by the specified customer id.
     * @param include - Optional. A comma-separated list of related resources to include in the response.
     * Related resources include: customer, account. [See Getting Related Resources](https://developers.unit.co/#intro-getting-related-resources)
     * @returns
     */
    async get(accountId, transactionId, customerId, include) {
        const parameters = {
            ...(customerId && { "filter[customerId]": customerId }),
            ...(include && { include })
        };
        return await this.httpGet(`/accounts/${accountId}/transactions/${transactionId}`, { params: parameters });
    }
    async list(params) {
        const parameters = {
            "page[limit]": ((params === null || params === void 0 ? void 0 : params.limit) ? params.limit : 100),
            "page[offset]": ((params === null || params === void 0 ? void 0 : params.offset) ? params.offset : 0),
            ...((params === null || params === void 0 ? void 0 : params.accountId) && { "filter[accountId]": params.accountId }),
            ...((params === null || params === void 0 ? void 0 : params.customerId) && { "filter[customerId]": params.customerId }),
            ...((params === null || params === void 0 ? void 0 : params.query) && { "filter[query]": params.query }),
            ...((params === null || params === void 0 ? void 0 : params.tags) && { "filter[tags]": params.tags }),
            ...((params === null || params === void 0 ? void 0 : params.since) && { "filter[since]": params.since }),
            ...((params === null || params === void 0 ? void 0 : params.until) && { "filter[until]": params.until }),
            ...((params === null || params === void 0 ? void 0 : params.cardId) && { "filter[cardId]": params.cardId }),
            ...((params === null || params === void 0 ? void 0 : params.excludeFees) && { "filter[excludeFees]": params.excludeFees }),
            ...((params === null || params === void 0 ? void 0 : params.fromAmount) && { "filter[fromAmount]": params.fromAmount }),
            ...((params === null || params === void 0 ? void 0 : params.toAmount) && { "filter[toAmount]": params.toAmount }),
            "sort": (params === null || params === void 0 ? void 0 : params.sort) ? params.sort : "-createdAt",
            "include": (params === null || params === void 0 ? void 0 : params.include) ? params.include : ""
        };
        if (params === null || params === void 0 ? void 0 : params.type)
            params.type.forEach((t, idx) => {
                parameters[`filter[type][${idx}]`] = t;
            });
        if (params === null || params === void 0 ? void 0 : params.direction)
            params.direction.forEach((d, idx) => {
                parameters[`filter[direction][${idx}]`] = d;
            });
        return await this.httpGet("/transactions", { params: parameters });
    }
    /**
     *
     * @param accountId
     * @param transactionId
     * @param tags - See [Updating Tags](https://developers.unit.co/#tags).
     * @returns
     */
    async update(request) {
        return await this.httpPatch(`/accounts/${request.accountId}/transactions/${request.transactionId}`, { data: request.data });
    }
}
exports.Transactions = Transactions;
